from setuptools import setup

setup(name='tim_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['tim_distributions'],
      author_email = 'clicklekan@gmail.com' ,
      zip_safe=False)
